@@ -96,7 +96,7 @@ xfpm_power_translate_technology (guint value)
   return _("Unknown");
 }
 
-const gchar *
+static const gchar *
 xfpm_battery_get_icon_index (guint percent)
 {
   if (percent < 10)
@@ -254,7 +254,7 @@ get_device_icon_name (UpClient *upower, UpDevice *device, gboolean is_panel)
   else if ( type == UP_DEVICE_KIND_MEDIA_PLAYER )
     icon_name = g_strdup (XFPM_MEDIA_PLAYER_ICON);
   else if ( type == UP_DEVICE_KIND_LINE_POWER )
-    icon_name = g_strdup_printf (is_panel ? "%s-%s", XFPM_AC_ADAPTER_ICON, "-symbolic" : "%s", XFPM_AC_ADAPTER_ICON);
+    icon_name = g_strdup_printf ("%s%s", XFPM_AC_ADAPTER_ICON, is_panel ? "-symbolic" : "");
   else if ( type == UP_DEVICE_KIND_MONITOR )
     icon_name = g_strdup (XFPM_MONITOR_ICON);
   else if ( type == UP_DEVICE_KIND_TABLET )
@@ -266,7 +266,7 @@ get_device_icon_name (UpClient *upower, UpDevice *device, gboolean is_panel)
   else if (!up_client_get_lid_is_present (upower) &&
            !up_client_get_on_battery (upower) &&
            g_strcmp0 (upower_icon, "battery-missing-symbolic") == 0)
-    icon_name = g_strdup_printf (is_panel ? "%s-%s", XFPM_AC_ADAPTER_ICON, "-symbolic" : "%s", XFPM_AC_ADAPTER_ICON);
+    icon_name = g_strdup_printf ("%s%s", XFPM_AC_ADAPTER_ICON, is_panel ? "-symbolic" : "");
   else if ( g_strcmp0 (upower_icon, "") != 0 )
     icon_name = g_strndup (upower_icon, icon_base_length);
 
@@ -340,17 +340,15 @@ get_device_description (UpClient *upower, UpDevice *device)
     if ( time_to_empty > 0 )
     {
       est_time_str = xfpm_battery_get_time_string (time_to_empty);
-      tip = g_strdup_printf (_("<b>%s %s</b>\nFully charged (%0.0f%%, %s runtime)"),
+      tip = g_strdup_printf (_("<b>%s %s</b>\nFully charged - %s remaining"),
                              vendor, model,
-                             percentage,
                              est_time_str);
       g_free (est_time_str);
     }
     else
     {
-      tip = g_strdup_printf (_("<b>%s %s</b>\nFully charged (%0.0f%%)"),
-                             vendor, model,
-                             percentage);
+      tip = g_strdup_printf (_("<b>%s %s</b>\nFully charged"),
+                             vendor, model);
     }
   }
   else if ( state == UP_DEVICE_STATE_CHARGING )
@@ -358,7 +356,7 @@ get_device_description (UpClient *upower, UpDevice *device)
     if ( time_to_full != 0 )
     {
       est_time_str = xfpm_battery_get_time_string (time_to_full);
-      tip = g_strdup_printf (_("<b>%s %s</b>\nCharging (%0.0f%%, %s)"),
+      tip = g_strdup_printf (_("<b>%s %s</b>\n%0.0f%% - %s until full"),
                              vendor, model,
                              percentage,
                              est_time_str);
@@ -366,7 +364,7 @@ get_device_description (UpClient *upower, UpDevice *device)
     }
     else
     {
-      tip = g_strdup_printf (_("<b>%s %s</b>\nCharging (%0.0f%%)"),
+      tip = g_strdup_printf (_("<b>%s %s</b>\n%0.0f%%"),
                              vendor, model,
                              percentage);
     }
@@ -376,7 +374,7 @@ get_device_description (UpClient *upower, UpDevice *device)
     if ( time_to_empty != 0 )
     {
       est_time_str = xfpm_battery_get_time_string (time_to_empty);
-      tip = g_strdup_printf (_("<b>%s %s</b>\nDischarging (%0.0f%%, %s)"),
+      tip = g_strdup_printf (_("<b>%s %s</b>\n%0.0f%% - %s remaining"),
                              vendor, model,
                              percentage,
                              est_time_str);
@@ -384,7 +382,7 @@ get_device_description (UpClient *upower, UpDevice *device)
     }
     else
     {
-      tip = g_strdup_printf (_("<b>%s %s</b>\nDischarging (%0.0f%%)"),
+      tip = g_strdup_printf (_("<b>%s %s</b>\n%0.0f%%"),
                              vendor, model,
                              percentage);
     }
